#
# spec file for package python-stack-data
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-stack-data
Version:        0.6.3
Release:        2.1
Summary:        Extract data from python stack frames and tracebacks
License:        MIT
URL:            https://github.com/alexmojaki/stack_data
Source:         https://files.pythonhosted.org/packages/source/s/stack_data/stack_data-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module setuptools >= 44}
BuildRequires:  %{python_module setuptools_scm >= 3.4.3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# PATCH-FIX-UPSTREAM https://github.com/alexmojaki/stack_data/pull/58 Modify test_executing_style_defs to work with Pygments 2.19
Patch0:         pygments.patch
Requires:       python-asttokens
Requires:       python-executing
Requires:       python-pure-eval
Suggests:       python-littleutils
Suggests:       python-pygments
Suggests:       python-pytest
Suggests:       python-typeguard
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module asttokens}
BuildRequires:  %{python_module executing}
BuildRequires:  %{python_module littleutils}
BuildRequires:  %{python_module pure-eval}
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typeguard}
# /SECTION
%python_subpackages

%description
Extract data from python stack frames and tracebacks for informative displays

%prep
%autosetup -p1 -n stack_data-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# incompatibility with even older Pygments
%pytest -k 'not ((test_core and test_pygments_example) or (test_serializer and test_example))'

%files %{python_files}
%{python_sitelib}/stack_data
%{python_sitelib}/stack_data-%{version}*-info

%changelog
* Mon Jan 20 2025 Markéta Machová <mmachova@suse.com>
- Add pygments.patch to fix non-skipped tests with Pygments 2.19
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * Python 3.12 support
  * handle weird six import error
- drop support-typeguard-4.patch (upstream)
* Wed Aug 23 2023 ecsos <ecsos@opensuse.org>
- Revert restrict to older Cython. Can not find any specification.
* Mon Aug 14 2023 Dirk Müller <dmueller@suse.com>
- skip more tests for newer pygments version
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- restrict to older Cython
* Mon May 15 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-typeguard-4.patch:
  * Support typeguard 4+.
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.2:
  * python 3.11 support
  * add tests
- drop 29-Pygments-2-12.patch  (upstream)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Jan  4 2023 Matej Cepl <mcepl@suse.com>
- Skip test_pygments_example test, because it is just too
  unstable given the ever changing output from Pygments.
* Mon May 16 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.2.0:
  - Fallback to basic Source.pieces when there is no Source.tree.
  - Handle nodes inside f-strings missing location info from
    asttokens
- Add 29-Pygments-2-12.patch (gh#alexmojaki/stack_data#29) making
  the package compabile with Pygments 2.12.
* Fri Jan 14 2022 Matej Cepl <mcepl@suse.com>
- Initial effort to package stack-data 0.1.3.
